@@ -8,9 +8,10 @@ from io import BytesIO
 import blinker
 
 from fresco.compat import unquote, urlparse
-from fresco.request import Request
+from fresco.request import Request, HEADER_NAMES as REQUEST_HEADER_NAMES
 from fresco.response import Response
-from fresco.util.urls import normpath
+from fresco.util.http import encode_multipart
+from fresco.util.urls import normpath, make_query
 from fresco.util.wsgi import unicode_to_environ
 
 from fresco.exceptions import ResponseException
@@ -21,6 +22,17 @@ from fresco.options import Options
 
 __all__ = ('FrescoApp', 'urlfor')
 
+#: The core keys expected in the WSGI environ dict, as defined by PEP3333
+WSGI_KEYS = set(['REQUEST_METHOD',
+                 'SCRIPT_NAME',
+                 'PATH_INFO',
+                 'QUERY_STRING',
+                 'CONTENT_TYPE',
+                 'CONTENT_LENGTH',
+                 'SERVER_NAME',
+                 'SERVER_PORT',
+                 'SERVER_PROTOCOL'])
+
 
 class FrescoApp(RouteCollection):
     """\
@@ -248,8 +260,8 @@ class FrescoApp(RouteCollection):
         return Response.method_not_allowed(valid_methods)
 
     @contextmanager
-    def requestcontext(self, url='http://localhost/', environ=None,
-                       wsgi_input=b'', **kwargs):
+    def requestcontext(self, url='/', environ=None,
+                       wsgi_input=b'', middleware=True, **kwargs):
         """
         Return the global :class:`fresco.requestcontext.RequestContext`
         instance, populated with a new request object modelling default
@@ -264,6 +276,18 @@ class FrescoApp(RouteCollection):
             http://www.example.com/view
 
         Note that ``url`` must be properly URL encoded.
+
+        :param url: The URL for the request,
+                    eg ``/index.html`` or ``/search?q=foo``.
+        :param environ: values to pass into the WSGI environ dict
+        :param wsgi_input: The input stream to use in the ``wsgi.input``
+                           key of the environ dict
+        :param middleware: If ``False`` the middleware stack will not be
+                           invoked. Disabling the middleware can speed up
+                           the execution considerably, but it will no longer
+                           give an accurate simulation of a real HTTP request.
+        :param kwargs: additional keyword arguments will be passed into the
+                       WSGI request environment
         """
         url = urlparse(url)
         netloc = url.netloc
@@ -281,6 +305,12 @@ class FrescoApp(RouteCollection):
         for key, value in kwargs.items():
             key = key.replace('wsgi_', 'wsgi.')
             if '.' not in key:
+                # Convert core WSGI keys to upper case
+                if key.upper() in WSGI_KEYS:
+                    key = key.upper()
+                # Convert header names to form HTTP_USER_AGENT
+                elif key.lower() in REQUEST_HEADER_NAMES:
+                    key = 'HTTP_' + key.upper()
                 # value must be a python native str, whatever that means
                 if not isinstance(value, str):
                     value = unicode_to_environ(value)
@@ -315,22 +345,67 @@ class FrescoApp(RouteCollection):
 
         environ.update(env_overrides)
 
-        if getattr(self, '_fakewsgiapp', None) is None:
-            def _fakewsgiapp(environ, start_response):
-                start_response('200 OK', [])
-                yield b''
-            self._fakewsgiapp = self._make_wsgi_app(_fakewsgiapp)
+        if middleware:
+            if getattr(self, '_fakewsgiapp', None) is None:
+                def _fakewsgiapp(environ, start_response):
+                    start_response('200 OK', [])
+                    yield b''
+                self._fakewsgiapp = self._make_wsgi_app(_fakewsgiapp)
 
-        # Invoke a fake wsgi app wrapped in all middleware layers. This
-        # executes any middleware, which may have side effects which are
-        # expected downstream (eg setting environ keys)
-        wsgi_iter = self._fakewsgiapp(environ, lambda *a, **kw: None)
-        next(wsgi_iter)
-        yield context
+            # Invoke a fake wsgi app wrapped in all middleware layers. This
+            # executes any middleware, which may have side effects which are
+            # expected downstream (eg setting environ keys)
+            wsgi_iter = self._fakewsgiapp(environ, lambda *a, **kw: None)
+            next(wsgi_iter)
+            yield context
 
-        # Exhaust the iterator and close up
-        list(wsgi_iter)
-        getattr(wsgi_iter, 'close', lambda: None)()
+            # Exhaust the iterator and close up
+            list(wsgi_iter)
+            getattr(wsgi_iter, 'close', lambda: None)()
+
+        else:
+            context.push(request=self.request_class(environ), app=self)
+            yield context
+            context.pop()
+
+    def requestcontext_with_payload(
+            self, url='/', data=None, environ=None, files=None,
+            multipart=False, **kwargs):
+
+        if files:
+            multipart = True
+
+        if multipart:
+            wsgi_input, headers = encode_multipart(data, files)
+            kwargs.update(headers)
+        elif hasattr(data, 'read'):
+            wsgi_input = data.read()
+        elif isinstance(data, bytes):
+            wsgi_input = data
+        else:
+            wsgi_input = make_query(data).encode('ascii')
+
+        if 'CONTENT_LENGTH' not in kwargs:
+            kwargs['CONTENT_LENGTH'] = str(len(wsgi_input))
+
+        return self.requestcontext(
+            url, environ, wsgi_input=wsgi_input, **kwargs)
+
+    def requestcontext_post(self, *args, **kwargs):
+        return self.requestcontext_with_payload(
+            REQUEST_METHOD='POST', *args, **kwargs)
+
+    def requestcontext_put(self, *args, **kwargs):
+        kwargs['REQUEST_METHOD'] = 'PUT'
+        return self.requestcontext_post(*args, **kwargs)
+
+    def requestcontext_patch(self, *args, **kwargs):
+        kwargs['REQUEST_METHOD'] = 'PATCH'
+        return self.requestcontext_post(*args, **kwargs)
+
+    def requestcontext_delete(self, *args, **kwargs):
+        kwargs['REQUEST_METHOD'] = 'DELETE'
+        return self.requestcontext(*args, **kwargs)
 
 
 def collect_keys(items):
