@@ -99,6 +99,18 @@ class MethodNotAllowed(ResponseException):
         self.response = Response.method_not_allowed(valid_methods)
 
 
+class TooManyRequests(ResponseException):
+    """
+    Indicates that the user has sent too many
+    requests in a given amount of time ("rate limiting").
+
+    The response representations SHOULD include details explaining the
+    condition, and MAY include a Retry-After header indicating how long
+    to wait before making a new request.
+    """
+    response = Response(['Too many requests'], status=429)
+
+
 class MissingRouteArg(BadRequest):
     """\
     A request argument was expected but not supplied.
