@@ -26,6 +26,58 @@ __all__ = 'Request', 'currentrequest'
 KB = 1024
 MB = 1024 * KB
 
+# List of standard request header field names
+# This is taken from the list available at
+# http://en.wikipedia.org/wiki/List_of_HTTP_header_fields which combines
+# RFC specified headers with commonly used non-standard header names
+HEADER_NAMES = {
+    'accept': 'Accept',
+    'accept_charset': 'Accept-Charset',
+    'accept_encoding': 'Accept-Encoding',
+    'accept_language': 'Accept-Language',
+    'accept_datetime': 'Accept-Datetime',
+    'authorization': 'Authorization',
+    'cache_control': 'Cache-Control',
+    'connection': 'Connection',
+    'cookie': 'Cookie',
+    'content_length': 'Content-Length',
+    'content_md5': 'Content-MD5',
+    'content_type': 'Content-Type',
+    'date': 'Date',
+    'expect': 'Expect',
+    'from': 'From',
+    'host': 'Host',
+    'if_match': 'If-Match',
+    'if_modified_since': 'If-Modified-Since',
+    'if_none_match': 'If-None-Match',
+    'if_range': 'If-Range',
+    'if_unmodified_since': 'If-Unmodified-Since',
+    'max_forwards': 'Max-Forwards',
+    'origin': 'Origin',
+    'pragma': 'Pragma',
+    'proxy_authorization': 'Proxy-Authorization',
+    'range': 'Range',
+    'referer': 'Referer',
+    'te': 'TE',
+    'user_agent': 'User-Agent',
+    'upgrade': 'Upgrade',
+    'via': 'Via',
+    'warning': 'Warning',
+    'common': 'Common',
+    'field': 'Field',
+    'x_requested_with': 'X-Requested-With',
+    'dnt': 'DNT',
+    'x_forwarded_for': 'X-Forwarded-For',
+    'x_forwarded_host': 'X-Forwarded-Host',
+    'x_forwarded_host': 'X-Forwarded-Host',
+    'x_forwarded_proto': 'X-Forwarded-Proto',
+    'front_end_https': 'Front-End-Https',
+    'x_http_method_override': 'X-Http-Method-Override',
+    'x_att_deviceid': 'X-ATT-DeviceId',
+    'x_wap_profile': 'X-Wap-Profile',
+    'proxy_connection': 'Proxy-Connection',
+}
+
 
 class Request(object):
     """
