@@ -320,6 +320,12 @@ class TestContextAttributes(object):
 
 class TestAppRequestContext(object):
 
+    def _middleware(self, app):
+        def middleware(environ, start_response):
+            environ['sausages'] = 1
+            return app(environ, start_response)
+        return middleware
+
     def test_creates_isolated_context(self):
 
         app = FrescoApp()
@@ -342,19 +348,46 @@ class TestAppRequestContext(object):
             assert context.request.environ['PATH_INFO'] == '/'
             assert context.request.environ['QUERY_STRING'] == 'x=y'
 
+    def test_it_posts_data(self):
+        with FrescoApp().requestcontext_post(data={'foo': 'bar'}) as c:
+            assert list(c.request.form.allitems()) == [('foo', 'bar')]
+            assert list(c.request.query.allitems()) == []
+
+    def test_it_posts_data_multipart(self):
+        with FrescoApp().requestcontext_post(
+                files=[('foo', 'foo.txt', 'text/plain', b'bar')]) as c:
+            assert c.request.files['foo'].filename == 'foo.txt'
+            assert c.request.files['foo'].file.read() == b'bar'
+
+    def test_it_posts_raw_data(self):
+        with FrescoApp().requestcontext_post(data=b'xyzzy',
+                                             content_type='text/spell') as c:
+            assert c.request.body == 'xyzzy'
+
+    def test_it_converts_header_names(self):
+        with FrescoApp().requestcontext(user_agent='foo'):
+            assert context.request.environ['HTTP_USER_AGENT'] == 'foo'
+
+    def test_it_converts_wsgi_keys(self):
+        # CONTENT_TYPE is both a WSGI core environ key and a standard request
+        # header. The WSGI key must win.
+        with FrescoApp().requestcontext(content_type='foo'):
+            assert context.request.environ['CONTENT_TYPE'] == 'foo'
+
     def test_it_invokes_middleware(self):
 
-        def middleware(app):
-            def middleware(environ, start_response):
-                environ['sausages'] = 1
-                return app(environ, start_response)
-            return middleware
-
         app = FrescoApp()
-        app.add_middleware(middleware)
+        app.add_middleware(self._middleware)
         with app.requestcontext() as c:
             assert 'sausages' in c.request.environ
 
+    def test_it_skips_middleware(self):
+
+        app = FrescoApp()
+        app.add_middleware(self._middleware)
+        with app.requestcontext(middleware=False) as c:
+            assert 'sausages' not in c.request.environ
+
     def test_it_closes_middleware(self):
 
         close = Mock()
@@ -483,8 +516,8 @@ class TestUrlfor(object):
         app = FrescoApp()
         app.include('/foo', fixtures.CBV('x'))
         with app.requestcontext():
-            assert urlfor('fresco.tests.fixtures.CBV.index_html') ==\
-                         'http://localhost/foo/'
+            assert urlfor('fresco.tests.fixtures.CBV.index_html') == \
+                        'http://localhost/foo/'
 
     def test_it_uses_values_from_path_defaults(self):
         app = FrescoApp()
