@@ -3,7 +3,7 @@ from copy import copy
 from functools import wraps
 
 from mock import Mock
-from flea import TestAgent
+from flea import Agent
 import pytest
 import tms
 
@@ -27,11 +27,11 @@ class TestMethodDispatch(object):
         app.route('/', GET, getview)
         app.route('/', POST, postview)
 
-        TestAgent(app).get('/')
+        Agent(app).get('/')
         assert getview.call_count == 1
         assert postview.call_count == 0
 
-        TestAgent(app).post('/')
+        Agent(app).post('/')
         assert getview.call_count == 1
         assert postview.call_count == 1
 
@@ -148,7 +148,7 @@ class TestPredicates(object):
         app.route('/', GET, v1, predicate=lambda request: 'x' in request.query)
         app.route('/', GET, v2, predicate=lambda request: 'y' in request.query)
 
-        t = TestAgent(app)
+        t = Agent(app)
         assert t.get('/?x=1', check_status=False).body == 'x'
         assert t.get('/?y=1', check_status=False).body == 'y'
         assert t.get('/', check_status=False).response.status_code == 404
@@ -335,7 +335,7 @@ class TestDelegatedRoutes(object):
         outer = FrescoApp()
         outer.delegate('/say', inner)
 
-        r = TestAgent(outer).get('/say/hello')
+        r = Agent(outer).get('/say/hello')
         assert r.body == 'hello'
 
     def test_url_variables_are_passed(self):
