@@ -114,8 +114,8 @@ class StartResponseWrapper(object):
         ...     responder.call_start_response()
         ...     return result
         ...
-        >>> from flea import TestAgent
-        >>> result = TestAgent(my_other_wsgi_app).get('/')
+        >>> from flea import Agent
+        >>> result = Agent(my_other_wsgi_app).get('/')
         Got status 200 OK
         Got headers [('Content-Type', 'text/plain')]
 
@@ -187,8 +187,8 @@ class ClosingIterator(object):
         ...     start_response('200 OK', [('Content-Type', 'text/plain')])
         ...     return ClosingIterator(iter(f.read, ''), f.close)
         ...
-        >>> from flea import TestAgent
-        >>> m = TestAgent(app).get('/')
+        >>> from flea import Agent
+        >>> m = Agent(app).get('/')
         file read!
         file closed!
 
